//
//  RyImagePickerChannel.swift
//  Runner
//
//  Created by Jerry on 2019/8/27.
//  Copyright © 2019 The Chromium Authors. All rights reserved.
//

import UIKit

open class RyImagePickerChannel: NSObject {
    
    public enum MediaType: String{
        case photoOrLib = "从相册选择"
        case camera = "拍照"
        case cancel = "取消"
    }
    
    public typealias PickeImageHandler = (URL) -> ()
    
    fileprivate var pickerVC:UIImagePickerController {
        let vc = UIImagePickerController()
        vc.delegate = self
        vc.allowsEditing = true
        return vc
    }
    
    public var sourceVC:UIViewController?
    
    private let actionController: UIAlertController = UIAlertController()
    
    public var imageHandler:PickeImageHandler?
    
    public init(_ picker:UIViewController) {
        self.sourceVC = picker
    }
    
    public func showImagePicker(handler:@escaping PickeImageHandler){
        
        self.imageHandler = handler
        
        let actionPhoto = UIAlertAction(title: MediaType.photoOrLib.rawValue, style: .default, handler: { action in
            let imagePickerController = self.pickerVC
            imagePickerController.sourceType = .photoLibrary
            self.sourceVC?.present(imagePickerController, animated: true, completion: nil)
        })
        
        actionController.addAction(actionPhoto)
        
        if UIImagePickerController.isSourceTypeAvailable(.camera){
            actionController.addAction(UIAlertAction(title: MediaType.camera.rawValue, style: .default, handler: { [weak self] _ in
                guard let weakself = self else {
                    return
                }
                let imagePickerController = weakself.pickerVC
                imagePickerController.sourceType = .camera
                weakself.sourceVC?.present(imagePickerController, animated: true, completion: nil)
            }))
        }
        
        actionController.addAction(UIAlertAction(title: MediaType.cancel.rawValue, style: .cancel, handler: nil))
        
        sourceVC?.present(actionController, animated: true, completion: nil)
    }
}

extension RyImagePickerChannel: UIImagePickerControllerDelegate,UINavigationControllerDelegate {
    
    private func imagePickerControllerDidCancel(_ picker: UIImagePickerController) {
        picker.dismiss(animated: true, completion: nil)
    }
    
    private func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [String : Any]) {
        if #available(iOS 11.0, *) {
            if let url = info[UIImagePickerControllerImageURL] as? URL,let handler = self.imageHandler{
                handler(url)
            } else {
                if let url = URL(string: "no data to return") {
                    imageHandler?(url)
                } else{
                    print("no data to return")
                }
                picker.dismiss(animated: true, completion: nil)
            }
        } else {
            // Fallback on earlier versions
        }
    }
    
}
